# eric7.Plugins.VcsPlugins.vcsSubversion.SvnBlameDialog

Module implementing a dialog to show the output of the svn blame command.

### Global Attributes

None

### Classes

SvnBlameDialog | Class implementing a dialog to show the output of the svn blame command.

### Functions

None

## SvnBlameDialog

Class implementing a dialog to show the output of the svn blame command.

### Derived from

QDialog, Ui_SvnBlameDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnBlameDialog | Constructor
__finish | Private slot called when the process finished or the user pressed the button.
__generateItem | Private method to generate a blame item in the blame list.
__procFinished | Private slot connected to the finished signal.
__readStderr | Private slot to handle the readyReadStderr signal.
__readStdout | Private slot to handle the readyReadStdout signal.
__resizeColumns | Private method to resize the list columns.
closeEvent | Protected slot implementing a close event handler.
keyPressEvent | Protected slot to handle a key press event.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_input_returnPressed | Private slot to handle the press of the return key in the input field.
on_passwordCheckBox_toggled | Private slot to handle the password checkbox toggled.
on_sendButton_clicked | Private slot to send the input to the subversion process.
start | Public slot to start the svn blame command.

### Static Methods

None

#### SvnBlameDialog (Constructor)

SvnBlameDialog(vcs, parent=None)

Constructor

vcs
  reference to the vcs object
parent
  parent widget (QWidget)

#### SvnBlameDialog.__finish

__finish()

Private slot called when the process finished or the user pressed the button.

#### SvnBlameDialog.__generateItem

__generateItem(revision, author, text)

Private method to generate a blame item in the blame list.

revision
  revision string (string)
author
  author of the change (string)
text
  line of text from the annotated file (string)

#### SvnBlameDialog.__procFinished

__procFinished(exitCode, exitStatus)

Private slot connected to the finished signal.

exitCode
  exit code of the process (integer)
exitStatus
  exit status of the process (QProcess.ExitStatus)

#### SvnBlameDialog.__readStderr

__readStderr()

Private slot to handle the readyReadStderr signal.

It reads the error output of the process and inserts it into the error pane.

#### SvnBlameDialog.__readStdout

__readStdout()

Private slot to handle the readyReadStdout signal.

It reads the output of the process, formats it and inserts it into the contents pane.

#### SvnBlameDialog.__resizeColumns

__resizeColumns()

Private method to resize the list columns.

#### SvnBlameDialog.closeEvent

closeEvent(e)

Protected slot implementing a close event handler.

e
  close event (QCloseEvent)

#### SvnBlameDialog.keyPressEvent

keyPressEvent(evt)

Protected slot to handle a key press event.

evt
  the key press event (QKeyEvent)

#### SvnBlameDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

#### SvnBlameDialog.on_input_returnPressed

on_input_returnPressed()

Private slot to handle the press of the return key in the input field.

#### SvnBlameDialog.on_passwordCheckBox_toggled

on_passwordCheckBox_toggled(isOn)

Private slot to handle the password checkbox toggled.

isOn
  flag indicating the status of the check box (boolean)

#### SvnBlameDialog.on_sendButton_clicked

on_sendButton_clicked()

Private slot to send the input to the subversion process.

#### SvnBlameDialog.start

start(fn)

Public slot to start the svn blame command.

fn
  filename to show the blame for (string)

Up